@@ -71,7 +71,7 @@ func TestNewVerifyCmd(t *testing.T) {
 				BundlePath:       test.NormalizeRelativePath("../test/data/sigstore-js-2.1.0-bundle.json"),
 				DigestAlgorithm:  "sha384",
 				Limit:            30,
-				OIDCIssuer:       GitHubOIDCIssuer,
+				OIDCIssuer:       verification.GitHubOIDCIssuer,
 				Owner:            "sigstore",
 				SigstoreVerifier: verification.NewMockSigstoreVerifier(t),
 				Hostname:         "github.com",
@@ -86,7 +86,7 @@ func TestNewVerifyCmd(t *testing.T) {
 				BundlePath:       test.NormalizeRelativePath("../test/data/sigstore-js-2.1.0-bundle.json"),
 				DigestAlgorithm:  "sha256",
 				Limit:            30,
-				OIDCIssuer:       GitHubOIDCIssuer,
+				OIDCIssuer:       verification.GitHubOIDCIssuer,
 				Owner:            "sigstore",
 				SANRegex:         "(?i)^https://github.com/sigstore/",
 				SigstoreVerifier: verification.NewMockSigstoreVerifier(t),
@@ -102,7 +102,7 @@ func TestNewVerifyCmd(t *testing.T) {
 				BundlePath:       test.NormalizeRelativePath("../test/data/sigstore-js-2.1.0-bundle.json"),
 				DigestAlgorithm:  "sha256",
 				Limit:            30,
-				OIDCIssuer:       "https://token.actions.foo.ghe.com",
+				OIDCIssuer:       verification.GitHubOIDCIssuer,
 				Owner:            "sigstore",
 				SANRegex:         "(?i)^https://foo.ghe.com/sigstore/",
 				SigstoreVerifier: verification.NewMockSigstoreVerifier(t),
@@ -118,7 +118,7 @@ func TestNewVerifyCmd(t *testing.T) {
 				BundlePath:       test.NormalizeRelativePath("../test/data/sigstore-js-2.1.0-bundle.json"),
 				DigestAlgorithm:  "sha256",
 				Limit:            30,
-				OIDCIssuer:       GitHubOIDCIssuer,
+				OIDCIssuer:       verification.GitHubOIDCIssuer,
 				Owner:            "sigstore",
 				SANRegex:         "(?i)^https://github.com/sigstore/",
 				SigstoreVerifier: verification.NewMockSigstoreVerifier(t),
@@ -134,7 +134,7 @@ func TestNewVerifyCmd(t *testing.T) {
 				BundlePath:       test.NormalizeRelativePath("../test/data/sigstore-js-2.1.0-bundle.json"),
 				DigestAlgorithm:  "sha512",
 				Limit:            30,
-				OIDCIssuer:       GitHubOIDCIssuer,
+				OIDCIssuer:       verification.GitHubOIDCIssuer,
 				Owner:            "sigstore",
 				SANRegex:         "(?i)^https://github.com/sigstore/",
 				SigstoreVerifier: verification.NewMockSigstoreVerifier(t),
@@ -148,7 +148,7 @@ func TestNewVerifyCmd(t *testing.T) {
 			wants: Options{
 				ArtifactPath:     test.NormalizeRelativePath("../test/data/sigstore-js-2.1.0.tgz"),
 				DigestAlgorithm:  "sha256",
-				OIDCIssuer:       GitHubOIDCIssuer,
+				OIDCIssuer:       verification.GitHubOIDCIssuer,
 				Owner:            "sigstore",
 				Limit:            30,
 				SANRegex:         "(?i)^https://github.com/sigstore/",
@@ -163,7 +163,7 @@ func TestNewVerifyCmd(t *testing.T) {
 			wants: Options{
 				ArtifactPath:     artifactPath,
 				DigestAlgorithm:  "sha256",
-				OIDCIssuer:       GitHubOIDCIssuer,
+				OIDCIssuer:       verification.GitHubOIDCIssuer,
 				Owner:            "sigstore",
 				Repo:             "sigstore/sigstore-js",
 				Limit:            30,
@@ -179,7 +179,7 @@ func TestNewVerifyCmd(t *testing.T) {
 				ArtifactPath:     artifactPath,
 				DigestAlgorithm:  "sha256",
 				Limit:            30,
-				OIDCIssuer:       GitHubOIDCIssuer,
+				OIDCIssuer:       verification.GitHubOIDCIssuer,
 				Owner:            "sigstore",
 				SANRegex:         "(?i)^https://github.com/sigstore/",
 				SigstoreVerifier: verification.NewMockSigstoreVerifier(t),
@@ -193,7 +193,7 @@ func TestNewVerifyCmd(t *testing.T) {
 			wants: Options{
 				ArtifactPath:     artifactPath,
 				DigestAlgorithm:  "sha256",
-				OIDCIssuer:       GitHubOIDCIssuer,
+				OIDCIssuer:       verification.GitHubOIDCIssuer,
 				Owner:            "sigstore",
 				Limit:            101,
 				SANRegex:         "(?i)^https://github.com/sigstore/",
@@ -208,7 +208,7 @@ func TestNewVerifyCmd(t *testing.T) {
 			wants: Options{
 				ArtifactPath:     artifactPath,
 				DigestAlgorithm:  "sha256",
-				OIDCIssuer:       GitHubOIDCIssuer,
+				OIDCIssuer:       verification.GitHubOIDCIssuer,
 				Owner:            "sigstore",
 				Limit:            0,
 				SANRegex:         "(?i)^https://github.com/sigstore/",
@@ -224,7 +224,7 @@ func TestNewVerifyCmd(t *testing.T) {
 				ArtifactPath:     artifactPath,
 				DigestAlgorithm:  "sha256",
 				Limit:            30,
-				OIDCIssuer:       GitHubOIDCIssuer,
+				OIDCIssuer:       verification.GitHubOIDCIssuer,
 				Owner:            "sigstore",
 				SAN:              "https://github.com/sigstore/",
 				SANRegex:         "(?i)^https://github.com/sigstore/",
@@ -241,7 +241,7 @@ func TestNewVerifyCmd(t *testing.T) {
 				BundlePath:       bundlePath,
 				DigestAlgorithm:  "sha256",
 				Limit:            30,
-				OIDCIssuer:       GitHubOIDCIssuer,
+				OIDCIssuer:       verification.GitHubOIDCIssuer,
 				Owner:            "sigstore",
 				SANRegex:         "(?i)^https://github.com/sigstore/",
 				SigstoreVerifier: verification.NewMockSigstoreVerifier(t),
@@ -331,7 +331,7 @@ func TestJSONOutput(t *testing.T) {
 		APIClient:        api.NewTestClient(),
 		Logger:           io.NewHandler(testIO),
 		OCIClient:        oci.MockClient{},
-		OIDCIssuer:       GitHubOIDCIssuer,
+		OIDCIssuer:       verification.GitHubOIDCIssuer,
 		Owner:            "sigstore",
 		SANRegex:         "^https://github.com/sigstore/",
 		SigstoreVerifier: verification.NewMockSigstoreVerifier(t),
@@ -354,7 +354,7 @@ func TestRunVerify(t *testing.T) {
 		APIClient:        api.NewTestClient(),
 		Logger:           logger,
 		OCIClient:        oci.MockClient{},
-		OIDCIssuer:       GitHubOIDCIssuer,
+		OIDCIssuer:       verification.GitHubOIDCIssuer,
 		Owner:            "sigstore",
 		SANRegex:         "^https://github.com/sigstore/",
 		SigstoreVerifier: verification.NewMockSigstoreVerifier(t),
@@ -474,7 +474,7 @@ func TestRunVerify(t *testing.T) {
 			APIClient:        api.NewTestClient(),
 			DigestAlgorithm:  "sha512",
 			Logger:           logger,
-			OIDCIssuer:       GitHubOIDCIssuer,
+			OIDCIssuer:       verification.GitHubOIDCIssuer,
 			Owner:            "sigstore",
 			SAN:              SigstoreSanValue,
 			SigstoreVerifier: verification.NewMockSigstoreVerifier(t),
